@@ -169,7 +169,7 @@ basesorresidues = Suppress("bases") | Suppress("residues")
 position = basesorresidues + integer("from") + Suppress("to") + integer("to")
 notes = Word(''.join(p for p in printables if p not in "()"))("notes")
 refloc = sup_lparen + Optional(position) + Optional(notes) + sup_rparen
-refdesc = integer("refid") + Group(refloc)
+refdesc = integer("refid") + Optional(Group(refloc))
 authors = Group(Literal("AUTHORS") + keywordnorm)
 consrtm = Group(Literal("CONSRTM") + keywordnorm)
 title = Group(Literal("TITLE") + keywordnorm)
@@ -314,6 +314,8 @@ def _k_reference(data):
         "from": getattr(res[1], "from", None),
         "to": getattr(res[1], "to", None)
     }
+    if not loc["from"] and not loc["to"]:
+        loc = None
     ref = {
         "refid": res[0],
         "location": loc,
@@ -461,7 +463,7 @@ _q_virion = lambda d: True
 known_qualifiers = set("""
 allele bond_type chromosome citation clone clone_lib coded_by codon_recognized
 country cultivar db_xref dev_stage direction ec_number evidence exception
-experiment function gene gene_synonym go_component go_function go_process
+experiment function gene gene_synonym go_component go_function go_process host
 inference isolate locus_tag map mobile_element mol_type note ncrna_class
 old_locus_tag operon organelle organism product protein_id region_name
 rpt_family site_type standard_name strain sub_strain tissue_type transcript_id
@@ -681,6 +683,10 @@ class Record(object):
     def __repr__(self):
         return "<Record %r>" % self.locus["name"]
 
+    def load_sequence(self):
+        self.sequence = ''.join(self.seqiter)
+        self.seqiter = None
+
     def exhaust(self):
         if not self.seqiter:
             return
